==> huaweicloudsdkiamaccessanalyzer-3.1.101-py2.py3-none-any.whl: huaweicloudsdkiamaccessanalyzer/v1/model/show_finding_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowFindingResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'finding': 'Finding'
    }

    attribute_map = {
        'finding': 'finding'
    }

    def __init__(self, finding=None):
        """ShowFindingResponse

        The model defined in huaweicloud sdk

        :param finding: 
        :type finding: :class:`huaweicloudsdkiamaccessanalyzer.v1.Finding`
        """
        
        super(ShowFindingResponse, self).__init__()

        self._finding = None
        self.discriminator = None

        if finding is not None:
            self.finding = finding

    @property
    def finding(self):
        """Gets the finding of this ShowFindingResponse.

        :return: The finding of this ShowFindingResponse.
        :rtype: :class:`huaweicloudsdkiamaccessanalyzer.v1.Finding`
        """
        return self._finding

    @finding.setter
    def finding(self, finding):
        """Sets the finding of this ShowFindingResponse.

        :param finding: The finding of this ShowFindingResponse.
        :type finding: :class:`huaweicloudsdkiamaccessanalyzer.v1.Finding`
        """
        self._finding = finding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowFindingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiamaccessanalyzer-3.1.152-py2.py3-none-any.whl: huaweicloudsdkiamaccessanalyzer/v1/model/show_finding_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowFindingResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'finding': 'Finding'
    }

    attribute_map = {
        'finding': 'finding'
    }

    def __init__(self, finding=None):
        r"""ShowFindingResponse

        The model defined in huaweicloud sdk

        :param finding: 
        :type finding: :class:`huaweicloudsdkiamaccessanalyzer.v1.Finding`
        """
        
        super(ShowFindingResponse, self).__init__()

        self._finding = None
        self.discriminator = None

        if finding is not None:
            self.finding = finding

    @property
    def finding(self):
        r"""Gets the finding of this ShowFindingResponse.

        :return: The finding of this ShowFindingResponse.
        :rtype: :class:`huaweicloudsdkiamaccessanalyzer.v1.Finding`
        """
        return self._finding

    @finding.setter
    def finding(self, finding):
        r"""Sets the finding of this ShowFindingResponse.

        :param finding: The finding of this ShowFindingResponse.
        :type finding: :class:`huaweicloudsdkiamaccessanalyzer.v1.Finding`
        """
        self._finding = finding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowFindingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
